mod entity;
mod handlers;
mod models;

use anyhow::{Error, Result};
use dotenv::dotenv;
use handlers::get_dispatcher;
use migration::{Migrator, MigratorTrait};
use sea_orm::Database;
use std::{env, future::Future, pin::Pin};

type PinnedFuture<'a, T> = Pin<Box<dyn Future<Output = T> + Send + 'a>>;

#[tokio::main]
async fn main() -> Result<()> {
    let _ = dotenv();
    pretty_env_logger::init();

    let token = env::var("TOKEN").unwrap();
    let database_url = env::var("DATABASE_URL").unwrap();
    let db = Database::connect(database_url).await?;
    Migrator::up(&db, None).await?;
    get_dispatcher(token, db).dispatch().await;
    Ok(())
}
